@@ -1,4 +1,4 @@
-// Copyright (C) 2009-2012 National ICT Australia (NICTA)
+// Copyright (C) 2009-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -111,6 +111,22 @@ mean(const T& x)
 
 
 
+template<typename T1>
+arma_inline
+const OpCube<T1, op_mean>
+mean
+  (
+  const BaseCube<typename T1::elem_type,T1>& X,
+  const uword dim = 0
+  )
+  {
+  arma_extra_debug_sigprint();
+  
+  return OpCube<T1, op_mean>(X.get_ref(), dim, 0);
+  }
+
+
+
 template<typename T1>
 inline
 arma_warn_unused
